==> haskell-pango-0.13.3.1-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-pango.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pango
version: 0.13.3.1
id: pango-0.13.3.1-5rCNhPf5uW2KBMjtiZBWLI
key: pango-0.13.3.1-5rCNhPf5uW2KBMjtiZBWLI
license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the Pango text rendering engine.
description:
    This package provides a wrapper around the Pango C library that
    allows high-quality rendering of Unicode text. It can be used
    either with Cairo to output text in PDF, PS or other
    documents or with Gtk+ to display text on-screen.
category: Graphics
author: Axel Simon, Duncan Coutts
exposed: True
indefinite: False
exposed-modules:
    Graphics.Rendering.Pango Graphics.Rendering.Pango.Attributes
    Graphics.Rendering.Pango.BasicTypes Graphics.Rendering.Pango.Cairo
    Graphics.Rendering.Pango.Context Graphics.Rendering.Pango.Enums
    Graphics.Rendering.Pango.Font Graphics.Rendering.Pango.Layout
    Graphics.Rendering.Pango.Markup Graphics.Rendering.Pango.Rendering
    Graphics.Rendering.Pango.Structs Graphics.Rendering.Pango.Types
hidden-modules: Graphics.Rendering.Pango.GlyphStorage
                Graphics.Rendering.Pango.Description
abi: 345f31e86bd2b4540e430f9ff967da07
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/pango-0.13.3.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/pango-0.13.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-pango
hs-libraries: HSpango-0.13.3.1-5rCNhPf5uW2KBMjtiZBWLI
extra-libraries:
    pangocairo-1.0 cairo pango-1.0 gobject-2.0 glib-2.0
include-dirs: /usr/include/pango-1.0 /usr/include/cairo
              /usr/include/pixman-1 /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/glib-2.0
              /usr/lib/glib-2.0/include
includes:
    hspango.h
depends:
    base-4.10.0.0 process-1.6.1.0 directory-1.3.0.2 array-0.5.2.0
    containers-0.5.10.2 pretty-1.1.3.3 mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    glib-0.13.4.1-Krxwx6yZMu0HfAhl5ALpGz
    cairo-0.13.3.1-IuWpw7LexbRALf36zecXA7
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             array-0.5.2.0=044554210403f250e868a2183de060a9
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             pretty-1.1.3.3=315e275f7256c4b9cea549968b2fd167
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             glib-0.13.4.1-Krxwx6yZMu0HfAhl5ALpGz=917401eec4696a3bf7373db9b7913301
             cairo-0.13.3.1-IuWpw7LexbRALf36zecXA7=d001b5e160cd123cdc1e4e31287a717a
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
haddock-interfaces: /usr/share/doc/haskell-pango/html/pango.haddock
haddock-html: /usr/share/doc/haskell-pango/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pango-0.13.4.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-pango.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pango
version: 0.13.4.0
id: pango-0.13.4.0-93N8KcCp9fjCcNiylbXI8X
key: pango-0.13.4.0-93N8KcCp9fjCcNiylbXI8X
license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the Pango text rendering engine.
description:
    This package provides a wrapper around the Pango C library that
    allows high-quality rendering of Unicode text. It can be used
    either with Cairo to output text in PDF, PS or other
    documents or with Gtk+ to display text on-screen.
category: Graphics
author: Axel Simon, Duncan Coutts
exposed: True
indefinite: False
exposed-modules:
    Graphics.Rendering.Pango Graphics.Rendering.Pango.Attributes
    Graphics.Rendering.Pango.BasicTypes Graphics.Rendering.Pango.Cairo
    Graphics.Rendering.Pango.Context Graphics.Rendering.Pango.Enums
    Graphics.Rendering.Pango.Font Graphics.Rendering.Pango.Layout
    Graphics.Rendering.Pango.Markup Graphics.Rendering.Pango.Rendering
    Graphics.Rendering.Pango.Structs Graphics.Rendering.Pango.Types
hidden-modules: Graphics.Rendering.Pango.GlyphStorage
                Graphics.Rendering.Pango.Description
abi: 8598a0d888b6990ab5e3526a21b01c7b
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/pango-0.13.4.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/pango-0.13.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/pango-0.13.4.0
hs-libraries: HSpango-0.13.4.0-93N8KcCp9fjCcNiylbXI8X
extra-libraries:
    pangocairo-1.0 cairo pango-1.0 gobject-2.0 glib-2.0
include-dirs: /usr/include/pango-1.0 /usr/include/cairo
              /usr/include/pixman-1 /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/glib-2.0
              /usr/lib/glib-2.0/include
includes:
    hspango.h
depends:
    base-4.10.0.0 process-1.6.1.0 directory-1.3.0.2 array-0.5.2.0
    containers-0.5.10.2 pretty-1.1.3.3 mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    glib-0.13.4.1-Krxwx6yZMu0HfAhl5ALpGz
    cairo-0.13.3.1-IuWpw7LexbRALf36zecXA7
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             array-0.5.2.0=044554210403f250e868a2183de060a9
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             pretty-1.1.3.3=315e275f7256c4b9cea549968b2fd167
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             glib-0.13.4.1-Krxwx6yZMu0HfAhl5ALpGz=917401eec4696a3bf7373db9b7913301
             cairo-0.13.3.1-IuWpw7LexbRALf36zecXA7=f3c7df8b4af5dd66e7ad140f8442558c
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
haddock-interfaces: /usr/share/doc/haskell-pango/html/pango.haddock
haddock-html: /usr/share/doc/haskell-pango/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
